const fs = require('fs')
const path = require('path')
const chalk = require('chalk')

const dbDir = path.join(__dirname, '../data')
const dbPath = path.join(dbDir, 'templates.json')

const fileExists = () => {
  try {
    if (!fs.existsSync(dbDir)) fs.mkdirSync(dbDir, { recursive: true })
    if (!fs.existsSync(dbPath)) fs.writeFileSync(dbPath, '[]')
    return true
  } catch {
    throw Error("Database file couldn't be created.")
  }
}

const getTemplates = () => {
  if (fileExists()) {
    return JSON.parse(fs.readFileSync(dbPath, 'utf8')).sort((a, b) => {
      if (a.name > b.name) return 1
      if (a.name < b.name) return -1
      return 0
    })
  }
}
const saveTemplates = templateDb => {
  fs.writeFileSync(dbPath, JSON.stringify(templateDb), 'utf8')
}

const getTemplateId = (templateDb, templateName) =>
  templateDb.findIndex(t => t.name === templateName)

module.exports.add = template => {
  const templateDb = getTemplates()
  if (template) {
    if (getTemplateId(templateDb, template.name) > -1) return false
    templateDb.push(template)
    saveTemplates(templateDb)
    return `[${chalk.cyan(
      template.name
    )}] has been added to available templates. To use, use 'forge i ${
      template.name
    }'.`
  }
}
module.exports.update = (template, newData) => {
  const templateDb = getTemplates()
  if (template) {
    let param
    if (newData.path) param = 'path'
    if (newData.repo) param = 'repo'

    let foundIdx = getTemplateId(templateDb, template.name)
    templateDb[foundIdx] = { ...templateDb[foundIdx], repo: newData[param] }

    saveTemplates(templateDb)
    return `[${chalk.cyan(
      template
    )}] has been updated. To use, use 'forge i ${template}'.`
  }
}
module.exports.delete = templateName => {
  fileExists()
  const templateDb = getTemplates()
  const idx = templateDb.findIndex(template => template.name === templateName)

  if (idx < 0) return false
  templateDb.splice(idx, 1)
  saveTemplates(templateDb)
  return true
}
module.exports.read = templateName => {
  fileExists()
  const templateJSON = getTemplates()
  if (!templateName) {
    return templateJSON
  }
  return templateJSON.find(template => template.name === templateName)
}
